@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2022 sqlmap developers (https://sqlmap.org/)
+Copyright (c) 2006-2023 sqlmap developers (https://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -154,15 +154,19 @@ def runThreads(numThreads, threadFunction, cleanupFunction=None, forwardExceptio
 
             if numThreads == 1:
                 warnMsg = "running in a single-thread mode. This could take a while"
-                logger.warn(warnMsg)
+                logger.warning(warnMsg)
 
         if numThreads > 1:
             if startThreadMsg:
                 infoMsg = "starting %d threads" % numThreads
                 logger.info(infoMsg)
         else:
-            _threadFunction()
-            return
+            try:
+                _threadFunction()
+            except (SqlmapUserQuitException, SqlmapSkipTargetException):
+                pass
+            finally:
+                return
 
         kb.multiThreadMode = True
 
