@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2022 sqlmap developers (https://sqlmap.org/)
+Copyright (c) 2006-2023 sqlmap developers (https://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -113,7 +113,7 @@ def _oneShotUnionUse(expression, unpack=True, limited=False):
                             for row in json.loads(output):
                                 retVal += "%s%s%s" % (kb.chars.start, kb.chars.delimiter.join(getUnicode(row[field] or NULL) for field in fields), kb.chars.stop)
                         except:
-                            pass
+                            retVal = None
                         else:
                             retVal = getUnicode(retVal)
                 elif Backend.isDbms(DBMS.PGSQL):
@@ -128,7 +128,7 @@ def _oneShotUnionUse(expression, unpack=True, limited=False):
                             for row in json.loads(output):
                                 retVal += "%s%s%s" % (kb.chars.start, row, kb.chars.stop)
                         except:
-                            pass
+                            retVal = None
                         else:
                             retVal = getUnicode(retVal)
 
@@ -167,7 +167,7 @@ def _oneShotUnionUse(expression, unpack=True, limited=False):
                 warnMsg = "possible server trimmed output detected "
                 warnMsg += "(probably due to its length and/or content): "
                 warnMsg += safecharencode(trimmed)
-                logger.warn(warnMsg)
+                logger.warning(warnMsg)
 
             elif re.search(r"ORDER BY [^ ]+\Z", expression):
                 debugMsg = "retrying failed SQL query without the ORDER BY clause"
@@ -252,7 +252,7 @@ def unionUse(expression, unpack=True, dump=False):
         debugMsg += "it does not play well with UNION query SQL injection"
         singleTimeDebugMessage(debugMsg)
 
-    if Backend.getIdentifiedDbms() in (DBMS.MYSQL, DBMS.ORACLE, DBMS.PGSQL, DBMS.MSSQL, DBMS.SQLITE) and expressionFields and not any((conf.binaryFields, conf.limitStart, conf.limitStop, conf.forcePartial)):
+    if Backend.getIdentifiedDbms() in (DBMS.MYSQL, DBMS.ORACLE, DBMS.PGSQL, DBMS.MSSQL, DBMS.SQLITE) and expressionFields and not any((conf.binaryFields, conf.limitStart, conf.limitStop, conf.forcePartial, conf.disableJson)):
         match = re.search(r"SELECT\s*(.+?)\bFROM", expression, re.I)
         if match and not (Backend.isDbms(DBMS.ORACLE) and FROM_DUMMY_TABLE[DBMS.ORACLE] in expression) and not re.search(r"\b(MIN|MAX|COUNT)\(", expression):
             kb.jsonAggMode = True
@@ -304,7 +304,7 @@ def unionUse(expression, unpack=True, dump=False):
                 warnMsg += "of entries for the SQL query provided. "
                 warnMsg += "sqlmap will assume that it returns only "
                 warnMsg += "one entry"
-                logger.warn(warnMsg)
+                logger.warning(warnMsg)
 
                 stopLimit = 1
 
@@ -312,7 +312,7 @@ def unionUse(expression, unpack=True, dump=False):
                 if not count:
                     warnMsg = "the SQL query provided does not "
                     warnMsg += "return any output"
-                    logger.warn(warnMsg)
+                    logger.warning(warnMsg)
                 else:
                     value = []  # for empty tables
                 return value
@@ -429,7 +429,7 @@ def unionUse(expression, unpack=True, dump=False):
 
                     warnMsg = "user aborted during enumeration. sqlmap "
                     warnMsg += "will display partial output"
-                    logger.warn(warnMsg)
+                    logger.warning(warnMsg)
 
                 finally:
                     for _ in sorted(threadData.shared.buffered):
