@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2021 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2023 sqlmap developers (https://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -126,7 +126,7 @@ class Fingerprint(GenericFingerprint):
 
             if not result:
                 warnMsg = "the back-end DBMS is not %s" % DBMS.FIREBIRD
-                logger.warn(warnMsg)
+                logger.warning(warnMsg)
 
                 return False
 
@@ -146,7 +146,7 @@ class Fingerprint(GenericFingerprint):
             return True
         else:
             warnMsg = "the back-end DBMS is not %s" % DBMS.FIREBIRD
-            logger.warn(warnMsg)
+            logger.warning(warnMsg)
 
             return False
 
