@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2020 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2023 sqlmap developers (https://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -42,7 +42,7 @@ def tamper(payload, **kwargs):
     >>> tamper('function()')
     'FuNcTiOn()'
     >>> tamper('SELECT id FROM `user`')
-    'SeLeCt Id FrOm `user`'
+    'SeLeCt id FrOm `user`'
     """
 
     retVal = payload
